@@ -18,7 +18,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 Mar 2012                                             }
+{ last modified: 31 May 2012                                             }
 {*************************************************************************/
 
 #ifndef QKINETICWIDGET_H
@@ -27,6 +27,7 @@
 #include <QtGui>
 
 #include "../alkatraz.h"
+#include "math.h"
 
 class QKineticWidget : public QWidget
 {
@@ -55,6 +56,8 @@ protected:
     QString cssNormal, cssActive;
     QWidget* activeWidget;
 
+    float _frx1, _frx1i, _frxlog, _fry1, _fry1i, _frylog;
+
     void mousePressEvent(QMouseEvent *event);
     void mouseMoveEvent(QMouseEvent *event);
     void mouseReleaseEvent(QMouseEvent *event);
@@ -87,8 +90,8 @@ public:
 
     inline float getFrictionX() const {return frictionX;}
     inline float getFrictionY() const {return frictionY;}
-    inline void setFrictionX(float value){frictionX = value;}
-    inline void setFrictionY(float value){frictionY = value;}
+    inline void setFrictionX(float value);
+    inline void setFrictionY(float value);
 
     inline int getMinX() const {return minX;}
     inline int getMinY() const {return minY;}
@@ -134,6 +137,11 @@ public:
 
     inline QWidget* getActiveWidget() const {return activeWidget;}
 
+    void rollToX(int targetX);
+    void rollToY(int targetY);
+    void rollToWidgetCenterX(QWidget* item);
+    void rollToWidgetCenterY(QWidget* item);
+
 signals:
     void onItemClick(QWidget* item);
     void onItemDown(QWidget* item);
