@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 19 May 2012                                              }
+{ last modified: 28 May 2012                                              }
 {*************************************************************************/
 
 #include "aboutwindow.h"
@@ -115,6 +115,9 @@ AboutWindow::AboutWindow(QWidget *parent) :
                 "After you (un)install a new gstreamer plugin, "
                 "you may click \"Select all supported\" button in \"File types\" window "
                 "to update filters list.");
+    hash["tip_search_enter"] = tr(
+                "In search window you can press Enter key instead of the \"search\" button. "
+                "You can also stop a current search by pressing Enter key.");
 
     initGui();
 }
