@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 31 May 2012                                              }
+{ last modified: 06 Jun 2012                                              }
 {*************************************************************************/
 
 #include "equalizerwindow.h"
@@ -432,11 +432,11 @@ void EqualizerWindow::onDeleteClick()
                     );
         return;
     }
-    if(QMessageBox::Ok == QMessageBox::question(
+    if(QMessageBox::Yes == QMessageBox::question(
                 this,
                 tr("Delete the preset"),
                 tr("Are you sure you want to delete the current preset?")+"\n\""+selectedPreset+"\"",
-                QMessageBox::Ok, QMessageBox::Cancel))
+                QMessageBox::Yes | QMessageBox::No, QMessageBox::No))
     {
         eq()->deletePreset(selectedPreset);
         eq()->setDefaultLevels();
