@@ -21,7 +21,7 @@
 { You may read GNU General Public License at:                             }
 {   http://www.gnu.org/copyleft/gpl.html                                  }
 {                                                                         }
-{ last modified: 29 May 2012                                              }
+{ last modified: 31 May 2012                                              }
 {*************************************************************************/
 
 #include "mainwindow.h"
@@ -124,7 +124,7 @@ void MainWindow::initGUI()
     connect(btnNext, SIGNAL(clicked()), SLOT(onBtnNextClick()));
     connect(btnParent, SIGNAL(clicked()), SLOT(onBtnParentClick()));
 
-    labelDir = new QLabel(this);
+    labelDir = new Label(this);
     labelDir->move(0, 0);
     QFont f = labelDir->font();
     f.setPixelSize(12);
@@ -245,12 +245,13 @@ void MainWindow::changeSkin(const QString &skinName)
     QString selWindows(
                 "MainWindow, OptionsWindow, SelectWindow, TypesWindow, "
                 "EqualizerWindow, TimerWindow, AboutWindow, SearchWindow");
-    QString selControls("QLabel, Button, QSlider, QButton");
+    QString selControls("Label, Button, Slider");
 
-    qApp->setStyleSheet(
-                selWindows+", "+selControls+" {"+skin->cssCommon+"} "+
-                selWindows+" {"+skin->cssCommonWindows+"} "+
-                selControls+" {"+skin->cssCommonControls+"} ");
+    QString sheet = selWindows+", "+selControls+" {"+skin->cssCommon+"} "+
+            selWindows+" {"+skin->cssCommonWindows+"} "+
+            selControls+" {"+skin->cssCommonControls+"} ";
+
+    qApp->setStyleSheet(sheet);
 
     btnPrev->setIcon(skin->icoPrev);
     btnStop->setIcon(skin->icoStop);
@@ -538,7 +539,8 @@ void MainWindow::playIndex(int index, bool doCloseCurrent)
     player->play(filename, doCloseCurrent);
 
     updateListIcons(true);
-    //cacheNext();
+    if(OPTIONS.centerCurrentTrack && currentFileItem)
+        itemsContainer->rollToWidgetCenterY(currentFileItem);
 }
 
 void MainWindow::stop()
@@ -819,6 +821,7 @@ void MainWindow::onStateChanged()
 void MainWindow::onTitleChange()
 {
     cacheNext();
+
     if(OPTIONS.popupTrackTitles)
     {
         // all that nonsense below is just for fitting all the text in notification window
@@ -1378,7 +1381,10 @@ void MainWindow::doCacheNext()
 
 void MainWindow::updateView()
 {
+    updateCurrentFileIndex();
     cd(fs->getCurrentDirectory());
+    if(OPTIONS.centerCurrentTrack && currentFileItem)
+        itemsContainer->rollToWidgetCenterY(currentFileItem);
 }
 
 void MainWindow::showStopTimerNotification()
