@@ -354,22 +354,22 @@
         <translation>Удалить этот файл</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="846"/>
+        <location filename="../src/mainwindow.cpp" line="849"/>
         <source>Cache has been cleared</source>
         <translation>Кэш очищен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="900"/>
+        <location filename="../src/mainwindow.cpp" line="903"/>
         <source>Equalizer module not found!</source>
         <translation>Модуль эквалайзера не найден!</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="917"/>
+        <location filename="../src/mainwindow.cpp" line="920"/>
         <source>The timer has been started</source>
         <translation>Таймер запущен</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="965"/>
+        <location filename="../src/mainwindow.cpp" line="968"/>
         <source>added %n more file(s)</source>
         <translation>
             <numerusform>добавлен ещё %n файл</numerusform>
@@ -378,83 +378,83 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1009"/>
+        <location filename="../src/mainwindow.cpp" line="1012"/>
         <source>Delete the file?</source>
         <translation>Удалить файл?</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="963"/>
+        <location filename="../src/mainwindow.cpp" line="966"/>
         <source>total files count</source>
         <translation>общее число файлов</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="967"/>
+        <location filename="../src/mainwindow.cpp" line="970"/>
         <source>no new files added</source>
         <translation>новых файлов не добавлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="982"/>
+        <location filename="../src/mainwindow.cpp" line="985"/>
         <source>this file will be played next</source>
         <translation>этот файл будет проигран следующим</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="991"/>
+        <location filename="../src/mainwindow.cpp" line="994"/>
         <source>files queued</source>
         <translation>файлов в очереди</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="992"/>
+        <location filename="../src/mainwindow.cpp" line="995"/>
         <source>this file has been added to queue</source>
         <translation>этот файл был добавлен в очередь</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1004"/>
+        <location filename="../src/mainwindow.cpp" line="1007"/>
         <source>filename</source>
         <translation>имя файла</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1005"/>
+        <location filename="../src/mainwindow.cpp" line="1008"/>
         <source>location</source>
         <translation>расположение</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1025"/>
+        <location filename="../src/mainwindow.cpp" line="1028"/>
         <source>Cannot delete the file</source>
         <translation>Нельзя удалить файл</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1029"/>
+        <location filename="../src/mainwindow.cpp" line="1032"/>
         <source>The file has been deleted</source>
         <translation>Файл был удалён</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1227"/>
+        <location filename="../src/mainwindow.cpp" line="1230"/>
         <source>off</source>
         <comment>eqActionLabel</comment>
         <translation>выкл.</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1230"/>
+        <location filename="../src/mainwindow.cpp" line="1233"/>
         <source>Equalizer</source>
         <translation>Эквалайзер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1324"/>
+        <location filename="../src/mainwindow.cpp" line="1327"/>
         <source>Playback has been stopped</source>
         <translation>Воспроизведение остановлено</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1386"/>
+        <location filename="../src/mainwindow.cpp" line="1390"/>
         <source>Timer has been stopped</source>
         <translation>Таймер остановлен</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1398"/>
+        <location filename="../src/mainwindow.cpp" line="1402"/>
         <source>Timer</source>
         <translation>Таймер</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="1402"/>
+        <location filename="../src/mainwindow.cpp" line="1406"/>
         <source>off</source>
         <translation>выкл.</translation>
     </message>
@@ -464,13 +464,13 @@
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="938"/>
-        <location filename="../src/mainwindow.cpp" line="954"/>
+        <location filename="../src/mainwindow.cpp" line="941"/>
+        <location filename="../src/mainwindow.cpp" line="957"/>
         <source>searching...</source>
         <translation>ищем...</translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/mainwindow.cpp" line="943"/>
+        <location filename="../src/mainwindow.cpp" line="946"/>
         <source>found %n file(s)</source>
         <translation>
             <numerusform>нашёлся %n файл</numerusform>
@@ -594,6 +594,11 @@
     </message>
     <message>
         <location filename="../src/optionswindow.cpp" line="98"/>
+        <source>Center a current track on track change</source>
+        <translation>Центрировать текущий трек при смене трека</translation>
+    </message>
+    <message>
+        <location filename="../src/optionswindow.cpp" line="99"/>
         <source>Skin</source>
         <translation>Скин</translation>
     </message>
